@@ -1,5 +1,5 @@
 package Getopt::EX::Colormap;
-use version; our $VERSION = version->declare("2.1.4");
+use version; our $VERSION = version->declare("2.1.5");
 
 use v5.14;
 use utf8;
@@ -98,10 +98,12 @@ sub color {
 
 sub colormap {
     my $obj = shift;
-    my %opt = @_;
-    $opt{name}    //= "--newopt";
-    $opt{option}  //= "--colormap";
-    $opt{sort}    //= "length";
+    my %opt = (
+	name   => "--newopt",
+	option => "--colormap",
+	sort   => "length",
+	@_
+    );
 
     my $hash = $obj->{HASH};
     join "\n", (
@@ -143,7 +145,7 @@ Getopt::EX::Colormap - ANSI terminal color and option support
   require Getopt::EX::Colormap;
   my $cm = Getopt::EX::Colormap
       ->new
-      ->load_params(@opt_colormap);  
+      ->load_params(@opt_colormap);
 
   print $cm->color('FILE', 'FILE labeled text');
 
@@ -285,7 +287,7 @@ at the module for detail.
     
     $handler->load_params(@opt_colormap);
     
-    for (0 .. $#colors) {
+    for (keys @colors) {
         print $handler->index_color($_, "COLOR $_"), "\n";
     }
     
