@@ -1,5 +1,5 @@
 package Getopt::EX::Long;
-use version; our $VERSION = version->declare("2.1.4");
+use version; our $VERSION = version->declare("2.1.5");
 
 use v5.14;
 use warnings;
@@ -119,7 +119,7 @@ sub new {
     my $class = shift;
 
     my @exconfig;
-    while (defined (my $i = first { $_[$_] eq 'exconfig' } 0 .. $#_)) {
+    while (defined (my $i = first { $_[$_] eq 'exconfig' } keys @_)) {
 	push @exconfig, @{ (splice @_, $i, 2)[1] };
     }
     if (@exconfig == 0 and $ConfigOption{AUTO_DEFAULT}) {
